@@ -35,7 +35,7 @@
 #ifndef STK_EXPRBASEFUNCTORS_H
 #define STK_EXPRBASEFUNCTORS_H
 
-#include "Arrays/include/STK_ExprBase.h"
+#include "STK_ExprBase.h"
 
 namespace STK
 {
@@ -50,34 +50,40 @@ template<typename Derived, typename Functor> struct ApplyWeightedFunctor;
 
 namespace hidden
 {
-/** @ingroup hidden
- *  helper class for choosing the ApplyFunctor.
+/** @ingroup hidden, Array
+ *  @brief Utility class allowing to get the correct Structure, Type, allocator,...
+ *  of the result when a functor is applied to an array.
+ *
+ *  @sa MinOp, MaxOp, MeanOp,MeanSafeOp
  **/
-template<class Derived, template<class> class Functor, bool isVector>
-struct ApplyFunctorChooser;
+template<typename Derived, template<class> class Functor, bool isVector_>
+struct FunctorSelector;
+
 
 /** @ingroup hidden
- *  specialization for general arrays: apply functor to rows or columns.
+ *  specialization for general arrays: apply functor to rows or columns
+ *  of the @c Derived array
  **/
 template<class Derived, template<class> class Functor>
-struct ApplyFunctorChooser<Derived, Functor, false>
+struct FunctorSelector<Derived, Functor, false>
 {
-  typedef typename Derived::Col VectorType;
-  typedef Functor<VectorType> ByColFunctor;
+  typedef typename Derived::Col Col;
+  typedef Functor<Col> ByColFunctor;
   typedef ApplyFunctorByCol<Derived, ByColFunctor> ColOp;
   typedef ApplyWeightedFunctorByCol<Derived, ByColFunctor> ColWeightedOp;
 
-  typedef typename Derived::Row PointType;
-  typedef Functor<PointType> ByRowFunctor;
+  typedef typename Derived::Row Row;
+  typedef Functor<Row> ByRowFunctor;
   typedef ApplyFunctorByRow<Derived, ByRowFunctor> RowOp;
   typedef ApplyWeightedFunctorByRow<Derived, ByRowFunctor> RowWeightedOp;
 };
 
 /** @ingroup hidden
- *  specialization for vectors and points.
+ *  specialization for vectors and points. In this case the functor apply
+ *  directly to the @c Derived class.
  **/
 template<class Derived, template<class> class Functor>
-struct ApplyFunctorChooser<Derived, Functor, true>
+struct FunctorSelector<Derived, Functor, true>
 {
   typedef Functor<Derived> ByColFunctor;
   typedef ApplyFunctor<Derived, ByColFunctor> ColOp;
@@ -94,7 +100,7 @@ struct ApplyFunctorChooser<Derived, Functor, true>
  *  or a vector if the data are in a matrix
  **/
 template<typename Derived, template<class> class Functor>
-struct ApplyFunctorSelector
+struct FunctorTraits
 {
   enum
   {
@@ -104,13 +110,13 @@ struct ApplyFunctorSelector
                    )
   };
 
-  typedef typename ApplyFunctorChooser<Derived, Functor, (bool)isVector_>::ColOp ColOp;
-  typedef typename ApplyFunctorChooser<Derived, Functor, (bool)isVector_>::ColWeightedOp ColWeightedOp;
-  typedef typename ApplyFunctorChooser<Derived, Functor, (bool)isVector_>::RowOp RowOp;
-  typedef typename ApplyFunctorChooser<Derived, Functor, (bool)isVector_>::RowWeightedOp RowWeightOp;
+  typedef typename FunctorSelector<Derived, Functor, (bool)isVector_>::ColOp ColOp;
+  typedef typename FunctorSelector<Derived, Functor, (bool)isVector_>::ColWeightedOp ColWeightedOp;
+  typedef typename FunctorSelector<Derived, Functor, (bool)isVector_>::RowOp RowOp;
+  typedef typename FunctorSelector<Derived, Functor, (bool)isVector_>::RowWeightedOp RowWeightedOp;
 
-  typedef typename ColOp::resultByColType resultByColType;
-  typedef typename RowOp::resultByRowType resultByRowType;
+  typedef typename ColOp::Row Row;
+  typedef typename RowOp::Col Col;
 };
 
 } // namespace hidden
@@ -122,39 +128,47 @@ template<typename Derived, typename Funct>
 struct ApplyFunctorByCol
 {
   typedef typename Derived::Type Type;
-  typedef CArrayPoint<Type> resultByColType;
+  enum
+  {
+    sizeRows_ = Derived::sizeRows_,
+    sizeCols_ = Derived::sizeCols_
+  };
+  typedef CArrayPoint<Type, sizeCols_> Row;
 
   /** constructor */
-  inline ApplyFunctorByCol( ExprBase<Derived> const& lhs) : lhs_(lhs.asDerived()) {}
+  inline ApplyFunctorByCol( ExprBase<Derived> const& lhs)
+                          : lhs_(lhs.asDerived())
+                          , res_(lhs_.cols())
+                          {}
   /** @return the applied functor by column */
-  resultByColType operator()()
+  Row operator()()
   {
-    resultByColType res(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
-    { res[j] = Funct(lhs_.col(j))();}
-    return res;
+    { res_[j] = Funct(lhs_.col(j))();}
+    return res_;
   }
   /** @return the applied functor by column */
-  resultByColType operator()(bool option)
+  Row operator()(bool option)
   {
-    resultByColType res(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
-    { res[j] = Funct(lhs_.col(j))( option);}
-    return res;
+    { res_[j] = Funct(lhs_.col(j))( option);}
+    return res_;
   }
   /** @return the applied functor by column */
-  resultByColType operator()(resultByColType const& value, bool option)
+  template<class OtherRow>
+  Row operator()(OtherRow const& value, bool option)
   {
 #ifdef STK_BOUNDS_CHECK
-  if (lhs_.cols() != value.cols()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByCol::operator(value,option),lhs_.cols()!=value.cols());
+  if (lhs_.cols() != value.range())
+    STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByCol::operator(value,option),lhs_.cols()!=value.range());
 #endif
-    resultByColType res(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
-    { res[j] = Funct(lhs_.col(j))(value[j], option);}
-    return res;
+    { res_[j] = Funct(lhs_.col(j))(value[j], option);}
+    return res_;
   }
   protected:
     Derived const& lhs_;
+    Row res_;
 };
 
 /** @ingroup Arrays
@@ -165,47 +179,53 @@ template<typename Derived, typename Funct>
 struct ApplyWeightedFunctorByCol
 {
   typedef typename Derived::Type Type;
-  typedef CArrayPoint<Type> resultByColType;
+  enum
+  {
+    sizeRows_ = Derived::sizeRows_,
+    sizeCols_ = Derived::sizeCols_
+  };
+  typedef CArrayPoint<Type, sizeCols_> Row;
 
   /** constructor */
-  inline ApplyWeightedFunctorByCol( ExprBase<Derived> const& lhs): lhs_(lhs.asDerived()) {}
+  inline ApplyWeightedFunctorByCol( ExprBase<Derived> const& lhs)
+                                  : lhs_(lhs.asDerived())
+                                  , res_(lhs_.cols())
+                                  {}
   template<class Weights>
-  resultByColType operator()(ExprBase<Weights> const& w)
+  Row operator()(ExprBase<Weights> const& w)
   {
-    resultByColType res_(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
     { res_[j] = Funct(lhs_.col(j))(w);}
     return res_;
   }
   template<class Weights>
-  resultByColType operator()(ExprBase<Weights> const& w, bool option)
+  Row operator()(ExprBase<Weights> const& w, bool option)
   {
-    resultByColType res_(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
     { res_[j] = Funct(lhs_.col(j))(w, option);}
     return res_;
   }
   template<class Weights>
-  resultByColType operator()(ExprBase<Weights> const& w, Type const& value)
+  Row operator()(ExprBase<Weights> const& w, Type const& value)
   {
-    resultByColType res_(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
     { res_[j] = Funct(lhs_.col(j))(w, value);}
     return res_;
   }
-  template< class Weights, typename OtherDerived>
-  resultByColType operator()(ExprBase<Weights> const& w, ExprBase<OtherDerived> const& value, bool option)
+  template< class Weights, typename OtherRow>
+  Row operator()(ExprBase<Weights> const& w, ExprBase<OtherRow> const& value, bool option)
   {
 #ifdef STK_BOUNDS_CHECK
-  if (lhs_.cols() != value.cols()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByCol::operator(w,value,option),lhs_.cols()!=value.cols());
+  if (lhs_.cols() != value.range())
+    STKRUNTIME_ERROR_NO_ARG(ApplyWeightedFunctorByCol::operator(w,value,option),lhs_.cols()!=value.range());
 #endif
-    resultByColType res_(lhs_.cols());
     for (int j= lhs_.beginCols(); j < lhs_.endCols(); ++j)
     { res_[j] = Funct(lhs_.col(j))(w, value[j], option);}
     return res_;
   }
   protected:
     Derived const& lhs_;
+    Row res_;
 };
 
 /** @ingroup Arrays
@@ -215,36 +235,43 @@ template<typename Derived, typename Funct>
 struct ApplyFunctorByRow
 {
   typedef typename Derived::Type Type;
-  typedef CArrayVector<Type> resultByRowType;
+  enum
+  {
+    sizeRows_ = Derived::sizeRows_,
+    sizeCols_ = Derived::sizeCols_
+  };
+  typedef CArrayVector<Type, sizeRows_> Col;
 
   /** constructor */
-  inline ApplyFunctorByRow( ExprBase<Derived> const& lhs) : lhs_(lhs.asDerived()) {}
-  resultByRowType operator()()
+  inline ApplyFunctorByRow( ExprBase<Derived> const& lhs)
+                          : lhs_(lhs.asDerived())
+                          , res_(lhs_.rows())
+                          {}
+  Col operator()()
   {
-    resultByRowType res(lhs_.rows());
     for (int i= lhs_.beginRows(); i < lhs_.endRows(); ++i)
-    { res[i] = Funct(lhs_.row(i))();}
-    return res;
+    { res_[i] = Funct(lhs_.row(i))();}
+    return res_;
   }
-  resultByRowType operator()(bool option)
+  Col operator()(bool option)
   {
-    resultByRowType res(lhs_.rows());
     for (int j= lhs_.beginRows(); j < lhs_.endRows(); ++j)
-    { res[j] = Funct(lhs_.row(j))( option);}
-    return res;
+    { res_[j] = Funct(lhs_.row(j))( option);}
+    return res_;
   }
-  resultByRowType operator()(resultByRowType const& value, bool option)
+  template<class OtherCol>
+  Col operator()(OtherCol const& value, bool option)
   {
 #ifdef STK_BOUNDS_CHECK
-  if (lhs_.rows() != value.rows()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByRow::operator(value,option),lhs_.rows()!=value.rows());
+  if (lhs_.rows() != value.range()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByRow::operator(value,option),lhs_.rows()!=value.rows());
 #endif
-    resultByRowType res(lhs_.rows());
     for (int j= lhs_.beginRows(); j < lhs_.endRows(); ++j)
-    { res[j] = Funct(lhs_.row(j))(value[j], option);}
-    return res;
+    { res_[j] = Funct(lhs_.row(j))(value[j], option);}
+    return res_;
   }
   protected:
     Derived const& lhs_;
+    Col res_;
 };
 
 /** @ingroup Arrays
@@ -254,64 +281,69 @@ template<typename Derived, typename Funct>
 struct ApplyWeightedFunctorByRow
 {
   typedef typename Derived::Type Type;
-  typedef CArrayVector<Type> resultByRowType;
+  enum
+  {
+    sizeRows_ = Derived::sizeRows_,
+    sizeCols_ = Derived::sizeCols_
+  };
+  typedef CArrayVector<Type, sizeRows_> Col;
 
   /** constructor */
-  inline ApplyWeightedFunctorByRow( ExprBase<Derived> const& lhs) : lhs_(lhs.asDerived()) {}
+  inline ApplyWeightedFunctorByRow( ExprBase<Derived> const& lhs)
+                                  : lhs_(lhs.asDerived())
+                                  , res_(lhs_.rows())
+                                  {}
   template<typename Weights>
-  resultByRowType operator()( ExprBase<Weights> const& w)
+  Col operator()( ExprBase<Weights> const& w)
   {
-    resultByRowType res_(lhs_.rows());
     for (int i= lhs_.beginRows(); i < lhs_.endRows(); ++i)
     { res_[i] = Funct(lhs_.row(i))(w);}
     return res_;
   }
   template<typename Weights>
-  resultByRowType operator()(ExprBase<Weights> const& w, bool option)
+  Col operator()(ExprBase<Weights> const& w, bool option)
   {
-    resultByRowType res_(lhs_.rows());
     for (int j= lhs_.beginRows(); j < lhs_.endRows(); ++j)
     { res_[j] = Funct(lhs_.row(j))(w, option);}
     return res_;
   }
-  template<typename Weights, typename OtherDerived>
-  resultByRowType operator()(ExprBase<Weights> const& w, Type const& value, bool option)
+//  template<typename Weights>
+//  Col operator()(ExprBase<Weights> const& w, Type const& value, bool option)
+//  {
+//#ifdef STK_BOUNDS_CHECK
+//  if (lhs_.rows() != value.rows()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByRow::operator(w,value,option),lhs_.rows()!=value.rows());
+//#endif
+//    for (int j= lhs_.beginRows(); j < lhs_.endRows(); ++j)
+//    { res_[j] = Funct(lhs_.row(j))(w, value, option);}
+//    return res_;
+//  }
+  template<typename Weights, typename OtherCol>
+  Col operator()(ExprBase<Weights> const& w, ExprBase<OtherCol> const& value, bool option)
   {
 #ifdef STK_BOUNDS_CHECK
-  if (lhs_.rows() != value.rows()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByRow::operator(w,value,option),lhs_.rows()!=value.rows());
+  if (lhs_.rows() != value.range()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByRow::operator(w,value,option),lhs_.rows()!=value.rows());
 #endif
-    resultByRowType res_(lhs_.rows());
-    for (int j= lhs_.beginRows(); j < lhs_.endRows(); ++j)
-    { res_[j] = Funct(lhs_.row(j))(w, value, option);}
-    return res_;
-  }
-  template<typename Weights, typename OtherDerived>
-  resultByRowType operator()(ExprBase<Weights> const& w, ExprBase<OtherDerived> const& value, bool option)
-  {
-#ifdef STK_BOUNDS_CHECK
-  if (lhs_.rows() != value.rows()) STKRUNTIME_ERROR_NO_ARG(ApplyFunctorByRow::operator(w,value,option),lhs_.rows()!=value.rows());
-#endif
-    resultByRowType res_(lhs_.rows());
     for (int j= lhs_.beginRows(); j < lhs_.endRows(); ++j)
     { res_[j] = Funct(lhs_.row(j))(w, value[j], option);}
     return res_;
   }
   protected:
     Derived const& lhs_;
+    Col res_;
 };
 
 /** @ingroup Arrays
- *  @brief class allowing applying the Functor Funct on a vector or row-vector
+ *  @brief class allowing applying the functor @c Funct on a vector or row-vector
  **/
 template<typename Derived, typename Funct>
 struct ApplyFunctor
 {
     typedef typename Derived::Type Type;
-    typedef Type resultByColType;
-    typedef Type resultByRowType;
+    typedef Type Col;
+    typedef Type Row;
     /// constructor
     inline ApplyFunctor( ExprBase<Derived> const& lhs) : lhs_(lhs.asDerived())
-    { STK_STATIC_ASSERT_VECTOR_ONLY(Derived);}
+    { STK_STATIC_ASSERT_POINT_OR_VECTOR_ONLY(Derived);}
     /** apply without argument*/
     inline Type operator()() { return Funct(lhs_)();}
     /** apply with an option argument*/
@@ -331,11 +363,11 @@ template<typename Derived, typename Funct>
 struct ApplyWeightedFunctor
 {
     typedef typename Derived::Type Type;
-    typedef Type resultByColType;
-    typedef Type resultByRowType;
+    typedef Type Col;
+    typedef Type Row;
     /// constructor
     inline ApplyWeightedFunctor( ExprBase<Derived> const& lhs): lhs_(lhs.asDerived())
-    { STK_STATIC_ASSERT_VECTOR_ONLY(Derived);}
+    { STK_STATIC_ASSERT_POINT_OR_VECTOR_ONLY(Derived);}
     /** apply with weights*/
     template<typename Weights>
     inline Type operator()(ExprBase<Weights> const& w) { return Funct(lhs_)(w);}
