@@ -28,14 +28,14 @@
  **/
 
 /** @file STK_Variable.h
- *  @brief Define a templated implementation of the interface class
- *  IVariable.
+ *  @brief Implement the interface class IVariable as Variable.
  **/
 
 #ifndef STK_VARIABLE_H
 #define STK_VARIABLE_H
 
-#include "Arrays/include/STK_IArray2D.h"
+#include <Arrays/include/STK_IArray1D.h>
+//#include <Arrays/include/STK_ExprBase.h>
 #include "STK_IVariable.h"
 
 namespace STK
@@ -60,26 +60,38 @@ struct Traits< Variable<Type_> >
 
   typedef Type_          Type;
   typedef typename RemoveConst<Type>::Type const& ReturnType;
+  typedef typename RemoveConst<Type>::Type const& ConstReturnType;
+
   enum
   {
     structure_ = Arrays::vector_,
     orient_    = Arrays::by_col_,
     sizeCols_  = 1,
     sizeRows_  = UnknownSize,
+    size_      = UnknownSize,
     storage_ = Arrays::dense_ // always dense
   };
+
+  typedef TRange<size_> RowRange;
+  typedef TRange<1>     ColRange;
+
+  typedef RandomIterator1D<Variable<Type_> > Iterator;
+  typedef ConstRandomIterator1D<Variable<Type_> > ConstIterator;
+
+  typedef std::reverse_iterator<Iterator> ReverseIterator;
+  typedef std::reverse_iterator<ConstIterator> ConstReverseIterator;
 };
 
 } // namespace hidden
 /** @ingroup DManager
   * @brief Variable is an implementation of the Base class IVariable
   * using The Array1D class for storing the data.
-  * It implement all purely virtual methods defined in the IVariable base
+  * It implements all purely virtual methods defined in the IVariable base
   * class.
  **/
 template<class Type>
 class Variable : public IVariable
-               , public IArray2D< Variable<Type> >
+               , public IArray1D< Variable<Type> >
 {
   public:
     typedef Variable<Type> Row;
@@ -91,117 +103,75 @@ class Variable : public IVariable
 
     enum
     {
-      structure_ = Arrays::vector_,
-      orient_    = Arrays::by_col_,
-      sizeCols_  = 1,
-      sizeRows_  = UnknownSize,
-      storage_ = Arrays::dense_ // always dense
+      structure_ = hidden::Traits<Variable<Type> >::structure_,
+      orient_    = hidden::Traits<Variable<Type> >::orient_,
+      size_      = hidden::Traits<Variable<Type> >::size_,
+      sizeCols_  = hidden::Traits<Variable<Type> >::sizeCols_,
+      sizeRows_  = hidden::Traits<Variable<Type> >::sizeRows_,
+      storage_   = hidden::Traits<Variable<Type> >::storage_
     };
     typedef AllocatorBase<Type*, UnknownSize> Allocator;
-    typedef IArray2D< Variable<Type> > Base;
-    typedef ArrayBase < Variable<Type> > LowBase;
+    typedef IArray1D< Variable<Type> > Base;
 
-    /** Default constructor */
-    Variable() : IVariable(IdTypeImpl<Type>::returnType(), stringNa)
-               , Base( Range(), Range(1)) {}
-    /** constructor
-     *  @param name : name of the variable
+    /** default constructor
+     *  @param name name of the variable
      **/
-    Variable( String const& name)
-            : IVariable(IdTypeImpl<Type>::returnType(), name)
-            , Base( Range(), Range(1))
+    explicit Variable( String const& name = stringNa)
+                     : IVariable(IdTypeImpl<Type>::returnType(), name)
+                     , Base()
     {}
     /** constructor
-     *  @param I : range of the data
+     *  @param size,name size and name of the variable
      **/
-    Variable( Range const& I)
-            : IVariable(IdTypeImpl<Type>::returnType(), stringNa)
-            , Base(I, Range(1))
+    explicit Variable( int size, String const& name = stringNa)
+                     : IVariable(IdTypeImpl<Type>::returnType(), name)
+                     , Base(size)
     {}
-    /** constructor
-     *  @param I : range of the data
-     *  @param name : name of the variable
+    /** Default constructor
+     *  @param I,name range and name of the variable
      **/
-    Variable( Range const& I, String const& name)
-            : IVariable(IdTypeImpl<Type>::returnType(), name)
-            , Base(I, Range(1))
+    explicit Variable( Range const& I, String const& name = stringNa)
+                     : IVariable(IdTypeImpl<Type>::returnType(), name)
+                     , Base(I)
     {}
-    /** Misc constructor
-     *  @param I : range of the data
-     *  @param name : name of the variable
-     *  @param v    : initial value
+    /** constructor with specified initial value
+     *  @param I,v range of the data and initial value
+     *  @param name name of the variable
      **/
     Variable( Range const& I, Type const& v, String const& name)
             : IVariable(IdTypeImpl<Type>::returnType(), name)
-            , Base(I, Range(1))
+            , Base(I)
     { this->setValue(v);}
-    /** Copy constructor.
+    /** copy/reference constructor.
      *  @param V the Variable to copy
      *  @param ref true if we want to wrap V
      **/
-    Variable( Variable const& V, bool ref = false)
-            : IVariable(V)
-            , Base(V, ref)
+    explicit Variable( Variable const& V, bool ref = false)
+                     : IVariable(V)
+                     , Base(V, ref)
     {}
-    /** Reference constructor
-     *  @param V the Variable to wrap
-     *  @param I range of the data
+    /** reference constructor
+     *  @param V,I Variable and range to wrap
      **/
-    Variable( Variable const& V, Range const& I)
-            : IVariable(V), Base(V, I, V.cols())
+    explicit Variable( Variable const& V, Range const& I)
+                     : IVariable(V), Base(V, I)
     {}
     /** constructor by reference, ref_=1.
      *  @param T the container to wrap
-     *  @param I the range of the data to wrap
-     *  @param col the index of the col to wrap
      **/
     template<class OtherArray>
-    Variable( IArray2D<OtherArray> const& T, Range const& I, int col)
+    Variable( IArray1D<OtherArray> const& T)
             : IVariable(IdTypeImpl<Type>::returnType(), stringNa)
-            , Base(T, I, Range(col, 1))
-    {
-        enum { value_ = hidden::isSame<Type, typename OtherArray::Type>::value };
-        STK_STATIC_ASSERT(value_,YOU_TRIED_TO_WRAP_A_CONTAINER_WITH_THE_WRONG_TYPE_AS_A_VARIABLE);
-    }
-    /** constructor by reference, ref_=1.
-     *  @param T the container to wrap
-     *  @param col the index of the col to wrap
+            , Base(T, T.range())
+    {}
+    /** Copy an other type of array/expression in a Variable.
+     *  @param T the array/expression to copy
      **/
     template<class OtherArray>
-    Variable( IArray2D<OtherArray> const& T, int col)
+    Variable( ExprBase<OtherArray> const& T)
             : IVariable(IdTypeImpl<Type>::returnType(), stringNa)
-            , Base(T, T.range(), Range(col, 1))
-    {
-      enum
-      {
-        value_ = hidden::isSame<Type, typename OtherArray::Type>::value,
-        is1D_ = ( (OtherArray::struct_ == Arrays::vector_)
-               || (OtherArray::struct_ == Arrays::point_)
-               || (OtherArray::struct_ == Arrays::diagonal_)
-               )
-      };
-      STK_STATIC_ASSERT(value_,YOU_TRIED_TO_WRAP_A_CONTAINER_WITH_THE_WRONG_TYPE_AS_A_VARIABLE);
-      STK_STATIC_ASSERT(is1D_,YOU_TRIED_TO_WRAP_A_CONTAINER_WHICH_IS_NOT_1D_AS_A_VARIABLE);
-    }
-    /** constructor by reference, ref_=1.
-     *  @param T the container to wrap
-     **/
-    template<class OtherArray>
-    Variable( IArray2D<OtherArray> const& T)
-            : IVariable(IdTypeImpl<Type>::returnType(), stringNa)
-            , Base(T, T.range(), T.cols())
-    {
-      enum
-      {
-        value_ = hidden::isSame<Type, typename OtherArray::Type>::value,
-        is1D_ = ( (OtherArray::structure_ == (int)Arrays::vector_)
-               || (OtherArray::structure_ == (int)Arrays::point_)
-               || (OtherArray::structure_ == (int)Arrays::diagonal_)
-               )
-      };
-      STK_STATIC_ASSERT(value_,YOU_TRIED_TO_WRAP_A_CONTAINER_WITH_THE_WRONG_TYPE_AS_A_VARIABLE);
-      STK_STATIC_ASSERT(is1D_,YOU_TRIED_TO_WRAP_A_CONTAINER_WHICH_IS_NOT_1D_AS_A_VARIABLE);
-    }
+            , Base(T)
+    {}
     /** destructor. */
     ~Variable() {}
     /** clone return a ptr on a copy of the Object.
@@ -209,58 +179,63 @@ class Variable : public IVariable
      **/
     virtual Variable* clone( bool ref = false) const
     { return new Variable(*this, ref);}
-    /** */
-    virtual void popBack(int const& n =1) { Base::popBackRows(n);}
     /** @return a constant reference on the ith element
      *  @param i index of the element (const)
      **/
-    inline Type const& elt1Impl(int const& i) const { return this->data(this->beginCols())[i];}
+    inline Type const& elt1Impl(int i) const { return this->data(i);}
     /** @return a reference on the ith element
      *  @param i index of the element
      **/
-    inline Type& elt1Impl(int const& i) { return this->data(this->beginCols())[i];}
+    inline Type& elt1Impl(int i) { return this->data(i);}
     /** New first index for the object.
      *  @param rbeg the index of the first row to set
      **/
-    void shift1D(int const& rbeg)
-    { Base::shift(rbeg, this->beginCols());}
+    void shift1D(int rbeg) { Base::shift(rbeg, this->beginCols());}
     /**  Resize the container.
      *  @param I the range to set to the container
      **/
     inline Variable<Type>& resize1D(Range const& I)
     { Base::resize(I, this->cols()); return *this;}
+
+    /** remove n elements to the end of the container
+     *  @param n number of element to remove */
+    virtual void popBack(int n =1) { Base::popBack(n);}
     /** Add n elements to the container.
      *  @param n number of elements to add
      **/
-    void pushBack( int const& n=1)
-    { Base::pushBackRows(n);}
+    void pushBack( int n=1) { Base::pushBack(n);}
     /** Add an element to the container.
      *  @param v the element to add
      **/
     void push_back( Type const& v)
-    { Base::pushBackRows();
+    { Base::pushBack();
       this->back() = v;
     }
     /** Insert n elements at the position pos of the container. The bound
      *  end_ should be modified at the very end of the insertion as pos
      *  can be a reference to it.
-     *  @param pos index where to insert elements
-     *  @param n number of elements to insert (default 1)
+     *  @param pos,n index and number of elements to insert
      **/
-    void insertElt(int pos, int const& n =1)
-    { Base::insertRows(pos, n);}
-    /** operator = : overwrite the CArray with the Right hand side T.
-     *  @param V the container to copy
-     **/
-    template<class Rhs>
-    inline Variable& operator=(Rhs const& V) { return LowBase::operator=(V);}
+    void insertElt(int pos, int n =1)
+    { Base::insertElt(pos, n);}
     /** operator = : overwrite the CArray with the Right hand side T.
      *  @param V the container to copy
      **/
     inline Variable& operator=(Variable const& V)
     { // copy IVariable part
       this->name_ = V.name_;
-      return LowBase::assign(V);
+      return Base::assign(V);
+    }
+    /** Copy an other type of array/expression in an Array1D.
+     *  @param T the array/expression to copy
+     **/
+    template<class OtherArray>
+    Variable& operator=(ExprBase<OtherArray> const& T)
+    {
+      // check size
+      if (this->size()!=T.size()) this->resize(T.range());
+      for (int i=this->begin(); i<this->end(); i++) this->elt(i)= T.elt(i);
+      return *this;
     }
     /** set the container to a constant value.
      *  @param v the value to set
@@ -278,7 +253,7 @@ class Variable : public IVariable
     void encode()
     { int code = baseIdx;
       std::pair< typename std::map<Type, int>::iterator, bool> ret;
-      for (int i=this->begin(); i<= this->lastIdx(); i++)
+      for (int i=this->begin(); i< this->end(); i++)
       { ret=coding_.insert(std::pair<Type, int>(this->elt(i), i));
         if (ret.second==true) { code++;}
       }
@@ -288,19 +263,13 @@ class Variable : public IVariable
     {
       typename String::size_type maxlength = with_name ? this->name().size() : 0;
       // loop over the values
-      for (int i=this->begin(); i<=this->lastIdx(); i++)
+      for (int i=this->begin(); i<this->end(); i++)
       { maxlength = std::max(maxlength, this->template eltAsString<Type>(i).size() );}
       return int(maxlength);
     }
     /** @return the number of missing values in the variable */
-    int nbMiss() const
-    {
-      int nbMiss = 0;
-      // loop over the values
-      for (int i=this->begin(); i<=this->lastIdx(); i++)
-      { if (Arithmetic<Type>::isNA(this->elt(i))) nbMiss++;}
-      return nbMiss;
-    }
+    int nbMiss() const;
+
     // IVariable part
     /** @return the number of sample in the variable */
     virtual int size() const { return Base::size();}
@@ -310,15 +279,15 @@ class Variable : public IVariable
      *  @param pos index where to delete elements
      *  @param n number of elements to delete (default 1)
      **/
-    virtual void erase(int pos, int const& n=1) { Base::eraseRows(pos,n);}
+    virtual void erase(int pos, int n=1) { Base::erase(pos,n);}
     /** New first index for the object.
      *  @param beg the index of the first column to set
      **/
-    virtual void shift(int const& beg) { Base::shift(beg);}
+    virtual void shift(int beg) { Base::shift(beg);}
     /** push back n NA values.
      *  @param n number of NA values to add
      **/
-    virtual inline void pushBackNAValues(int const& n=1);
+    virtual inline void pushBackNAValues(int n=1);
     /** Overwrite the variable V by converting the data into strings.
      *  @param V Variable of String
      **/
@@ -347,13 +316,23 @@ class Variable : public IVariable
     std::map<Type, int> coding_;
 };
 
+/** @return the number of missing values in the variable */
+template<class Type>
+int Variable<Type>::nbMiss() const
+{
+  int nbMiss = 0;
+  // loop over the values
+  for (int i=this->begin(); i<this->end(); i++)
+  { if (Arithmetic<Type>::isNA(this->elt(i))) nbMiss++;}
+  return nbMiss;
+}
 /** push back n NA values. Specialization for Type = String.
  *  @param n number of NA values to add
  **/
 template<>
-inline void Variable<String>::pushBackNAValues(int const& n)
-{ int first = this->lastIdx() +1, end = first+n;
-  this->insertRows(this->lastIdx() +1, n);
+inline void Variable<String>::pushBackNAValues(int n)
+{ int first = this->end(), end = first+n;
+  this->insertElt(this->end(), n);
   for (int i=first; i<end; i++)
   this->elt(i) = stringNa;
 }
@@ -361,10 +340,10 @@ inline void Variable<String>::pushBackNAValues(int const& n)
  *  @param n number of NA values to add
  **/
 template<class Type>
-inline void Variable<Type>::pushBackNAValues(int const& n)
+inline void Variable<Type>::pushBackNAValues(int n)
 {
-    int first = this->lastIdx() +1, end = first+n;
-    this->insertRows(this->lastIdx() +1, n);
+    int first = this->end(), end = first+n;
+    this->insertElt(this->end(), n);
     for (int i=first; i<end; i++)
     this->elt(i) =  Arithmetic<Type>::NA();
 }
@@ -376,8 +355,8 @@ inline void Variable<Type>::pushBackNAValues(int const& n)
  **/
 template<>
 inline int Variable<String>::importFromString( Variable< String > const& V
-                                        , std::ios_base& (*f)(std::ios_base&)
-                                    )
+                                             , std::ios_base& (*f)(std::ios_base&)
+                                             )
 { *this = V; return V.size();}
 /** overwrite the Variable by converting the strings
  *  contained in V into the Type.
@@ -393,7 +372,7 @@ inline int Variable<Type>::importFromString( Variable< String > const& V
   this->resize(V.range());
   this->setName(V.name());
   int nSuccess = V.size();
-  for (int i=V.begin(); i<=V.lastIdx(); i++)
+  for (int i=V.begin(); i<V.end(); i++)
     if ( (Arithmetic<String>::isNA(V[i])) || (V[i]==stringNa) ) // not Available
       this->elt(i) = Arithmetic<Type>::NA();
     else
@@ -426,7 +405,7 @@ inline Variable<String>& Variable<String>::operator<<( Variable< String > const&
 {
   this->resize(V.range());
   this->setName(V.name());
-  for (int i=V.begin(); i<=V.lastIdx(); i++) this->elt(i) = V[i];
+  for (int i=V.begin(); i<V.end(); i++) this->elt(i) = V[i];
   return *this;
 }
 /** Operator << : overwrite the Variable by converting the Strings
@@ -438,7 +417,7 @@ inline Variable<Type>& Variable<Type>::operator<<( Variable< String > const& V)
 {
   this->resize(V.range());
   this->setName(V.name());
-  for (int i=V.begin(); i<=V.lastIdx(); i++) this->elt(i) = stringToType<Type>(V[i]);
+  for (int i=V.begin(); i<V.end(); i++) this->elt(i) = stringToType<Type>(V[i]);
   return *this;
 }
 /** Operator >> : convert the Variable V into strings.
@@ -449,7 +428,7 @@ inline Variable<String> const& Variable<String>::operator>>(Variable< String >&
 {
   V.resize(this->range());
   V.setName(this->name());
-  for (int i=this->begin(); i<=this->lastIdx(); i++) V[i] = this->elt(i);
+  for (int i=this->begin(); i<this->end(); i++) V[i] = this->elt(i);
   return *this;
 }
 /** Operator >> : convert the Variable V into strings.
@@ -460,7 +439,7 @@ inline Variable<Type> const& Variable<Type>::operator>>(Variable< String >& V) c
 {
   V.resize(this->range());
   V.setName(this->name());
-  for (int i=this->begin(); i<=this->lastIdx(); i++) V[i] = typeToString<Type>(this->elt(i));
+  for (int i=this->begin(); i<this->end(); i++) V[i] = typeToString<Type>(this->elt(i));
   return *this;
 }
 /** ostream for Variable. */
@@ -468,7 +447,7 @@ template<typename Type>
 inline ostream& operator<<(ostream& s, Variable<Type> const& V)
 {
   s << V.name() << _T("\n");
-  return out2D(s,V);
+  return out1D(s, V);
 }
 
 } // namespace STK
