@@ -149,28 +149,28 @@ class Geometric: public IUnivLaw<Integer>
 
 
 inline int Geometric::rand() const
-{ GetRNGstate(); int s = ::Rf_rgeom(prob_);
+{ GetRNGstate(); int s = Rf_rgeom(prob_);
   PutRNGstate(); return s;
 }
 inline Real Geometric::pdf(Integer const& x) const
-{ return ::Rf_dgeom((double)x, prob_, false);}
+{ return Rf_dgeom((double)x, prob_, false);}
 inline Real Geometric::lpdf(Integer const& x) const
-{ return ::Rf_dgeom((double)x, prob_, true);}
+{ return Rf_dgeom((double)x, prob_, true);}
 inline Real Geometric::cdf(Real const& t) const
-{ return ::Rf_pgeom(t, prob_, true, false);}
+{ return Rf_pgeom(t, prob_, true, false);}
 inline int Geometric::icdf(Real const& p) const
-{ return ::Rf_qgeom(p, prob_, true, false);}
+{ return Rf_qgeom(p, prob_, true, false);}
 
 inline int Geometric::rand(Real const& prob)
-{ GetRNGstate(); int s = ::Rf_rgeom(prob);
+{ GetRNGstate(); int s = Rf_rgeom(prob);
   PutRNGstate(); return s;
 }
 inline Real Geometric::pdf(Integer x, Real const& prob)
-{ return ::Rf_dgeom((double)x, prob, false);}
+{ return Rf_dgeom((double)x, prob, false);}
 inline Real Geometric::lpdf(Integer x, Real const& prob)
-{ return ::Rf_dgeom((double)x, prob, true);}
+{ return Rf_dgeom((double)x, prob, true);}
 inline Real Geometric::cdf(Real const& t, Real const& prob)
-{ return ::Rf_pgeom(t, prob, true, false);}
+{ return Rf_pgeom(t, prob, true, false);}
 inline Integer Geometric::icdf(Real const& p, Real const& prob)
 { return (Integer)::Rf_qgeom(p, prob, true, false);}
 
